EXPORTS
	??0CPushMsgEntryBase@@QAE@XZ @ 1 NONAME ; public: __thiscall CPushMsgEntryBase::CPushMsgEntryBase(void)
	??0CWapPushMsgUtils@@IAE@XZ @ 2 NONAME ; protected: __thiscall CWapPushMsgUtils::CWapPushMsgUtils(void)
	??1CPushMsgEntryBase@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CPushMsgEntryBase::~CPushMsgEntryBase(void)
	??1CWapPushMsgUtils@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CWapPushMsgUtils::~CWapPushMsgUtils(void)
	?AppID@CPushMsgEntryBase@@QBEHAAVTPtrC8@@AAH1@Z @ 5 NONAME ; public: int __thiscall CPushMsgEntryBase::AppID(class TPtrC8 &,int &,int &)const 
	?ConstructL@CPushMsgEntryBase@@MAEXABH@Z @ 6 NONAME ; protected: virtual void __thiscall CPushMsgEntryBase::ConstructL(int const &)
	?ConstructL@CPushMsgEntryBase@@MAEXABVTPtrC8@@@Z @ 7 NONAME ; protected: virtual void __thiscall CPushMsgEntryBase::ConstructL(class TPtrC8 const &)
	?ConstructL@CPushMsgEntryBase@@MAEXXZ @ 8 NONAME ; protected: virtual void __thiscall CPushMsgEntryBase::ConstructL(void)
	?ConstructL@CWapPushMsgUtils@@IAEXXZ @ 9 NONAME ; protected: void __thiscall CWapPushMsgUtils::ConstructL(void)
 	?DummyExport@@YAXXZ @10 NONAME ; void Dummyexport(void)
	?ExternalizeL@CPushMsgEntryBase@@MAEXAAVRMsvWriteStream@@@Z @ 11 NONAME ; protected: virtual void __thiscall CPushMsgEntryBase::ExternalizeL(class RMsvWriteStream &)
	?From@CPushMsgEntryBase@@QBEABVTDesC8@@XZ @ 12 NONAME ; public: class TDesC8 const & __thiscall CPushMsgEntryBase::From(void)const 
	?GetServiceIdL@CWapPushMsgUtils@@QAEXVTUid@@AAJ@Z @ 13 NONAME ; public: void __thiscall CWapPushMsgUtils::GetServiceIdL(class TUid,long &)
	?Header@CPushMsgEntryBase@@QBEABVTDesC8@@XZ @ 14 NONAME ; public: class TDesC8 const & __thiscall CPushMsgEntryBase::Header(void)const 
	?InternalizeL@CPushMsgEntryBase@@MAEXAAVRMsvReadStream@@@Z @ 15 NONAME ; protected: virtual void __thiscall CPushMsgEntryBase::InternalizeL(class RMsvReadStream &)
	?MsgDescription@CPushMsgEntryBase@@QBEABVTDesC16@@XZ @ 16 NONAME ; public: class TDesC16 const & __thiscall CPushMsgEntryBase::MsgDescription(void)const 
	?MsgDetails@CPushMsgEntryBase@@QBEABVTDesC16@@XZ @ 17 NONAME ; public: class TDesC16 const & __thiscall CPushMsgEntryBase::MsgDetails(void)const 
	?NewL@CWapPushMsgUtils@@SAPAV1@XZ @ 18 NONAME ; public: static class CWapPushMsgUtils * __cdecl CWapPushMsgUtils::NewL(void)
	?ReceivedDate@CPushMsgEntryBase@@QBEABVTTime@@XZ @ 19 NONAME ; public: class TTime const & __thiscall CPushMsgEntryBase::ReceivedDate(void)const 
	?RestoreL@CPushMsgEntryBase@@IAEXAAVCMsvStore@@@Z @ 20 NONAME ; protected: void __thiscall CPushMsgEntryBase::RestoreL(class CMsvStore &)
	?RetrieveL@CPushMsgEntryBase@@UAEXAAVCMsvSession@@J@Z @ 21 NONAME ; public: virtual void __thiscall CPushMsgEntryBase::RetrieveL(class CMsvSession &,long)
	?SaveL@CPushMsgEntryBase@@UAEJAAVCMsvSession@@J@Z @ 22 NONAME ; public: virtual long __thiscall CPushMsgEntryBase::SaveL(class CMsvSession &,long)
	?SetEntry@CPushMsgEntryBase@@QAEXABVTMsvEntry@@@Z @ 23 NONAME ; public: void __thiscall CPushMsgEntryBase::SetEntry(class TMsvEntry const &)
	?SetFromL@CPushMsgEntryBase@@QAEXABVTDesC8@@@Z @ 24 NONAME ; public: void __thiscall CPushMsgEntryBase::SetFromL(class TDesC8 const &)
	?SetHeaderL@CPushMsgEntryBase@@QAEXABVTDesC8@@@Z @ 25 NONAME ; public: void __thiscall CPushMsgEntryBase::SetHeaderL(class TDesC8 const &)
	?SetMsgDescriptionL@CPushMsgEntryBase@@QAEXABVTDesC16@@@Z @ 26 NONAME ; public: void __thiscall CPushMsgEntryBase::SetMsgDescriptionL(class TDesC16 const &)
	?SetMsgDetailsL@CPushMsgEntryBase@@QAEXABVTDesC16@@@Z @ 27 NONAME ; public: void __thiscall CPushMsgEntryBase::SetMsgDetailsL(class TDesC16 const &)
	?SetStatus@CPushMsgEntryBase@@QAEXH@Z @ 28 NONAME ; public: void __thiscall CPushMsgEntryBase::SetStatus(int)
	?UpdateL@CPushMsgEntryBase@@UAEXAAVCMsvSession@@@Z @ 29 NONAME ; public: virtual void __thiscall CPushMsgEntryBase::UpdateL(class CMsvSession &)

